import { ThemeProvider, Flex } from '@chakra-ui/react';
import {
  Icon,
  IconNames,
  IconRotationTypes,
} from '@nypl/design-system-react-components';
import * as React from 'react';
import { ReaderReturn } from '../types';
import Header from './Header';
import useColorModeValue from './hooks/useColorModeValue';
import PageButton from './PageButton';
import { getTheme } from './theme';

/**
 * The default Manager UI. This will be broken into individual components
 * that can be imported and used separately or in a customized setup.
 * It takes the return value of useWebReader as props
 */
const ManagerUI: React.FC<ReaderReturn> = (props) => {
  return (
    <ThemeProvider theme={getTheme(props.state?.colorMode ?? 'day')}>
      <WebReaderContent {...props} />
    </ThemeProvider>
  );
};

const WebReaderContent: React.FC<ReaderReturn> = ({ children, ...props }) => {
  const bgColor = useColorModeValue('ui.white', 'ui.black', 'ui.sepia');
  return (
    <Flex flexDir="column" minHeight="100vh" w="100vw">
      {!props.isLoading && <Header {...props} />}
      <PageButton
        onClick={props.navigator?.goBackward}
        left={0}
        pr={2}
        aria-label="Previous Page"
      >
        <Icon
          decorative
          name={IconNames.arrow}
          modifiers={['small']}
          iconRotation={IconRotationTypes.rotate90}
        />
      </PageButton>
      <Flex
        width="100vw"
        bg={bgColor}
        // accounting for the prev/next buttons
        px={{ sm: 10, md: '5vw' }}
        flexDir="column"
        alignItems="stretch"
        flex="1 1 100%"
      >
        {children}
      </Flex>
      <PageButton
        onClick={props.navigator?.goForward}
        right={0}
        pl={2}
        aria-label="Next Page"
      >
        <Icon
          decorative
          name={IconNames.arrow}
          modifiers={['small']}
          iconRotation={IconRotationTypes.rotate270}
        />
      </PageButton>
    </Flex>
  );
};

export default ManagerUI;
